#[repr(C)]pub struct Equity {Show 19 fields
pub id: InstrumentId,
pub raw_symbol: Symbol,
pub isin: Option<Ustr>,
pub currency: Currency,
pub price_precision: u8,
pub price_increment: Price,
pub margin_init: Decimal,
pub margin_maint: Decimal,
pub maker_fee: Decimal,
pub taker_fee: Decimal,
pub lot_size: Option<Quantity>,
pub max_quantity: Option<Quantity>,
pub min_quantity: Option<Quantity>,
pub max_price: Option<Price>,
pub min_price: Option<Price>,
pub tick_scheme: Option<Ustr>,
pub info: Option<Params>,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Represents a generic equity instrument.
Fields
id: InstrumentIdThe instrument ID.
raw_symbol: SymbolThe raw/local/native symbol for the instrument, assigned by the venue.
isin: Option<Ustr>The instruments International Securities Identification Number (ISIN).
currency: CurrencyThe futures contract currency.
price_precision: u8The price decimal precision.
price_increment: PriceThe minimum price increment (tick size).
margin_init: DecimalThe initial (order) margin requirement in percentage of order value.
margin_maint: DecimalThe maintenance (position) margin in percentage of position value.
maker_fee: DecimalThe fee rate for liquidity makers as a percentage of order value.
taker_fee: DecimalThe fee rate for liquidity takers as a percentage of order value.
lot_size: Option<Quantity>The rounded lot unit size (standard/board).
max_quantity: Option<Quantity>The maximum allowable order quantity.
min_quantity: Option<Quantity>The minimum allowable order quantity.
max_price: Option<Price>The maximum allowable quoted price.
min_price: Option<Price>The minimum allowable quoted price.
tick_scheme: Option<Ustr>The registered variable tick scheme name.
info: Option<Params>Additional instrument metadata as a JSON-serializable dictionary.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the data event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the data object was initialized.
Implementations
Sourceimpl Equity
impl Equity
Sourcepub fn new_checked(
instrument_id: InstrumentId,
raw_symbol: Symbol,
isin: Option<Ustr>,
currency: Currency,
price_precision: u8,
price_increment: Price,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
tick_scheme: Option<Ustr>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> CorrectnessResult<Self>
pub fn new_checked( instrument_id: InstrumentId, raw_symbol: Symbol, isin: Option<Ustr>, currency: Currency, price_precision: u8, price_increment: Price, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, tick_scheme: Option<Ustr>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> CorrectnessResult<Self>
Sourcepub fn new(
instrument_id: InstrumentId,
raw_symbol: Symbol,
isin: Option<Ustr>,
currency: Currency,
price_precision: u8,
price_increment: Price,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
tick_scheme: Option<Ustr>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> Self
pub fn new( instrument_id: InstrumentId, raw_symbol: Symbol, isin: Option<Ustr>, currency: Currency, price_precision: u8, price_increment: Price, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, tick_scheme: Option<Ustr>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> Self
Sourcepub fn build_checked(
instrument_id: InstrumentId,
raw_symbol: Symbol,
isin: Option<Ustr>,
currency: Currency,
price_precision: u8,
price_increment: Price,
lot_size: Option<Quantity>,
max_quantity: Option<Quantity>,
min_quantity: Option<Quantity>,
max_price: Option<Price>,
min_price: Option<Price>,
margin_init: Option<Decimal>,
margin_maint: Option<Decimal>,
maker_fee: Option<Decimal>,
taker_fee: Option<Decimal>,
tick_scheme: Option<Ustr>,
info: Option<Params>,
ts_event: UnixNanos,
ts_init: UnixNanos,
) -> CorrectnessResult<Self>
pub fn build_checked( instrument_id: InstrumentId, raw_symbol: Symbol, isin: Option<Ustr>, currency: Currency, price_precision: u8, price_increment: Price, lot_size: Option<Quantity>, max_quantity: Option<Quantity>, min_quantity: Option<Quantity>, max_price: Option<Price>, min_price: Option<Price>, margin_init: Option<Decimal>, margin_maint: Option<Decimal>, maker_fee: Option<Decimal>, taker_fee: Option<Decimal>, tick_scheme: Option<Ustr>, info: Option<Params>, ts_event: UnixNanos, ts_init: UnixNanos, ) -> CorrectnessResult<Self>
Returns a fluent builder for a Equity instance.
Required fields are enforced at compile time; optional fields can be omitted and default
the same way they do in Equity::new_checked, which the builder calls so the same
correctness checks run on build.
Errors
Returns an error if any input validation fails (see Equity::new_checked).
Sourcepub fn builder() -> EquityBuildCheckedBuilder
pub fn builder() -> EquityBuildCheckedBuilder
Returns a fluent builder for a Equity instance.
Required fields are enforced at compile time; optional fields can be omitted and default
the same way they do in Equity::new_checked, which the builder calls so the same
correctness checks run on build.
Errors
Returns an error if any input validation fails (see Equity::new_checked).